pub struct ForeignToplevelList { /* private fields */ }Implementations
Sourceimpl ForeignToplevelList
impl ForeignToplevelList
pub fn new<D>(globals: &GlobalList, qh: &QueueHandle<D>) -> Selfwhere
D: Dispatch<ExtForeignToplevelListV1, GlobalData> + 'static,
Sourcepub fn info(
&self,
toplevel: &ExtForeignToplevelHandleV1,
) -> Option<ForeignToplevelInfo>
pub fn info( &self, toplevel: &ExtForeignToplevelHandleV1, ) -> Option<ForeignToplevelInfo>
Returns information about a toplevel.
This may be none if the toplevel has been destroyed or the compositor has not sent information about the toplevel yet.
pub fn stop(&self)